@@ -4,7 +4,7 @@ from datetime import date, datetime
 from decimal import Decimal
 from enum import Enum, unique
 from functools import singledispatch
-from typing import Any, Collection, Dict, List, Optional, Set, Type, Union
+from typing import Any, Collection
 
 import dateutil
 import sqlalchemy as sa
