@@ -2,7 +2,7 @@
 from __future__ import annotations
 
 from datetime import date, datetime
-from typing import TYPE_CHECKING, Container, Dict, Set
+from typing import TYPE_CHECKING, Container
 
 import structlog
 
